@@ -158,11 +158,13 @@ class MyWhatify:
         return my_toolkit.Prediction.run_prescriptive(pred_id=pred_id, features=features, target_value=target_value)
 
     @classmethod
-    def upload_data_file(cls, data_file, data_name, wait=True, skip_if_exists=True, na_values=None):
+    def upload_data_file(cls, data_name, data_file=None, wait=True, skip_if_exists=True, na_values=None):
         with allure.step('uploading csv name: ' + data_name + ' with wait= ' + str(wait) +
-                     ' and skip if exist= ' + str(skip_if_exists)):
+                         ' and skip if exist= ' + str(skip_if_exists)):
             source_id = -1
             try:
+                if not data_file:
+                    data_file = cls.get_data_file_s3(file_name=data_name)
                 source_id = my_toolkit.Datasource.create_from_dataframe(df=data_file, data_source_name=data_name,
                                                                         wait=wait, skip_if_exists=skip_if_exists,
                                                                         na_values=na_values)['id']
